@@ -202,7 +202,6 @@ irplib_framelist * irplib_framelist_cast(const cpl_frameset * frameset)
 {
 
     irplib_framelist * self;
-    const cpl_frame * frame;
     int i;
 
 
@@ -213,7 +212,7 @@ irplib_framelist * irplib_framelist_cast(const cpl_frameset * frameset)
 
     for (i = 0; i < cpl_frameset_get_size(frameset); i++) 
     {
-        frame = cpl_frameset_get_position_const(frameset, i);
+        const cpl_frame * frame = cpl_frameset_get_position_const(frameset, i);
 
         cpl_frame * copy = cpl_frame_duplicate(frame);
 
