@@ -85,7 +85,6 @@ static double PSF_H2(double, double);
 static double PSF_G(double, double);
 static double PSF_sinc_norm(double);
 static double PSF_TelOTF(double, double);
-static cpl_error_code update_bad_pixel_map(cpl_image* im);
 
 #ifndef IRPLIB_NO_FIT_GAUSSIAN
 #ifdef IRPLIB_STREHL_USE_CPL_IMAGE_FIT_GAUSSIAN
@@ -113,103 +112,6 @@ cpl_error_code irplib_gaussian_maxpos(const cpl_image *,
  -----------------------------------------------------------------------------*/
 /**@{*/
 
-/**
-  @brief    Update the bad pixel map for the image - mark all pixels with NaN value as a bad
-  @param    im             Image with pixel-type float or double
-  @return CPL_ERROR_NONE or the relevant CPL error code on error
-  */
-cpl_error_code update_bad_pixel_map(cpl_image* im)
-{
-	int szx = cpl_image_get_size_x(im);
-	int szy = cpl_image_get_size_y(im);
-	int x = 0;
-	cpl_mask* bpm = cpl_image_get_bpm(im);
-
-	for (x = 1; x <=szx; x++)
-	{
-		int y = 0;
-		for(y = 1; y <= szy; y++)
-		{
-			int isnull = 0;
-			double value = cpl_image_get(im, x, y, &isnull);
-			if (isnan(value))
-			{
-				cpl_mask_set(bpm, x, y, CPL_BINARY_1);
-			}
-		}
-	}
-	return cpl_error_get_code();
-}
-/**
-  @brief    Compute the strehl ratio in an image.
-  @param    im             Image with pixel-type float
-  @param    m1             Diameter of the M1 mirror [m]
-  @param    m2             Diameter of the M2 mirror [m]
-  @param    lam            Central wavelength [micron]
-  @param    dlam           Filter bandwidth [micron]
-  @param    pscale         Positive pixel scale
-  @param    size           Size of image to be used for internal PSF
-  @param    xpos           The x position of the ring center
-  @param    ypos           The y position of the ring center
-  @param    r1             The Star Radius, r1 > 0
-  @param    r2             The Internal Radius, r2 > 0
-  @param    r3             The External Radius, r3 > r2
-  @param    noise_box_sz   Pass -1 for default values
-  @param    noise_nsamples Pass -1 for default values
-  @param    strehl         Pointer to the Strehl Error (positive on success)
-  @param    strehl_err     Pointer to the Strehl Error (non-negative on success)
-  @param    star_bg        Pointer to the Star Background
-  @param    star_peak      Pointer to the Star Peak (positive on success)
-  @param    star_flux      Pointer to the Star Flux (positive on success)
-  @param    psf_peak       Pointer to the PSF Peak (positive on success)
-  @param    psf_flux       Pointer to the PSF Flux (1 on success)
-  @param    bg_noise       Pointer to the Background Noise
-  @return  CPL_ERROR_NONE or the relevant CPL error code on error
-  @note     The output is undefined on error. On success the Strehl Ratio may
-            exceed 1. Before computation, all NaN values in the image would be marked in the
-            bad pixel map. That means, parameter im would changed (bad pixel map would be updated / created).
-  */
-
-cpl_error_code irplib_strehl_mark_bad_and_compute(cpl_image *   im,
-                                     double              m1,
-                                     double              m2,
-                                     double              lam,
-                                     double              dlam,
-                                     double              pscale,
-                                     int                 size,
-                                     double              xpos,
-                                     double              ypos,
-                                     double              r1,
-                                     double              r2,
-                                     double              r3,
-                                     int                 noise_box_sz,
-                                     int                 noise_nsamples,
-                                     double          *   strehl,
-                                     double          *   strehl_err,
-                                     double          *   star_bg,
-                                     double          *   star_peak,
-                                     double          *   star_flux,
-                                     double          *   psf_peak,
-                                     double          *   psf_flux,
-                                     double          *   bg_noise)
-{
-	cpl_ensure_code(!update_bad_pixel_map(im), cpl_error_get_code());
-	return irplib_strehl_compute(im, m1, m2, lam, dlam, pscale, size, xpos, ypos,
-            r1,
-            r2,
-            r3,
-            noise_box_sz,
-            noise_nsamples,
-            strehl,
-            strehl_err,
-            star_bg,
-            star_peak,
-            star_flux,
-            psf_peak,
-            psf_flux,
-            bg_noise);
-}
-
 /*----------------------------------------------------------------------------*/
 /**
   @brief    Compute the strehl ratio in an image
@@ -237,9 +139,8 @@ cpl_error_code irplib_strehl_mark_bad_and_compute(cpl_image *   im,
   @param    psf_flux       Pointer to the PSF Flux (1 on success)
   @param    bg_noise       Pointer to the Background Noise
   @return   CPL_ERROR_NONE or the relevant CPL error code on error
-  @see rplib_strehl_mark_bad_and_compute() for input with NaNs not marked as bad
   @note     The output is undefined on error. On success the Strehl Ratio may
-            exceed 1.
+            exceed 1. Any pixel flagged as bad is ignored.
  */
 /*----------------------------------------------------------------------------*/
 cpl_error_code irplib_strehl_compute(const cpl_image *   im,
@@ -277,7 +178,7 @@ cpl_error_code irplib_strehl_compute(const cpl_image *   im,
     /* cpl_flux_get_noise_ring() must succeed with this many tries */
     int          ring_tries = 3;
 #ifndef IRPLIB_NO_FIT_GAUSSIAN
-    double xposfit, yposfit, peak;
+    double xposfit = 0.0, yposfit = 0.0, peak = 0.0;
     cpl_error_code code;
 #endif
     cpl_errorstate prestate = cpl_errorstate_get();
@@ -377,7 +278,6 @@ cpl_error_code irplib_strehl_compute(const cpl_image *   im,
 #endif
 
     /* Compute Strehl error */
-    /* computation could fail if the image contains pixels with NaN value*/
     ring[0] = xpos;
     ring[1] = ypos;
     ring[2] = r2/pscale;
@@ -423,9 +323,6 @@ cpl_error_code irplib_strehl_compute(const cpl_image *   im,
   @note     (xpos, ypos) and may be outside the image, if so then a sufficiently
             small rad will cause no pixels to be encircled, in which case the
             returned flux is zero.
-
-  The nan values check has been added for SINFONI. The input image in
-  input should not contain nan values, but it does in  some cases...
  */
 /*----------------------------------------------------------------------------*/
 double irplib_strehl_disk_flux(const cpl_image * im,
@@ -461,7 +358,7 @@ double irplib_strehl_disk_flux(const cpl_image * im,
                 int isbad;
                 const double value = cpl_image_get(im, i+1, j+1, &isbad);
 
-                if (!isbad && irplib_isnan(value) == 0) {
+                if (!isbad ) {
 
                     flux += value - bg;
 
@@ -484,8 +381,6 @@ double irplib_strehl_disk_flux(const cpl_image * im,
   @param    mode        IRPLIB_BG_METHOD_AVER_REJ or IRPLIB_BG_METHOD_MEDIAN
   @return   The computed background or 0.0 on error.
 
-  The nan values check has been added for SINFONI. The input image in
-  input should not contain nan values, but it does in  some cases...
  */
 /*----------------------------------------------------------------------------*/
 double irplib_strehl_ring_background(const cpl_image *       im,
@@ -536,7 +431,7 @@ double irplib_strehl_ring_background(const cpl_image *       im,
                 int isbad;
                 const double value = cpl_image_get(im, i+1, j+1, &isbad);
 
-                if (!isbad && irplib_isnan(value) == 0) {
+                if (!isbad) {
                     cpl_vector_set(pix_arr, npix, value);
                     npix++;
                 }
@@ -710,7 +605,8 @@ static cpl_image * irplib_strehl_generate_otf(double  m1,
                 const double x = (double)i;
                 const double y = (double)j;
                 const double sqdist = x * x + y * y;
-                double f_lambda, sinc_xy_9 = 0.0; /* Zero if OTF is zero */
+                double f_lambda = 0.0;
+                double sinc_xy_9 = 0.0; /* Zero if OTF is zero */
                 double otfxy = 0.0;
                 int k;
 
@@ -871,7 +767,7 @@ cpl_error_code irplib_strehl_disk_max(const cpl_image * self,
                 int isbad;
                 const double value = cpl_image_get(self, i+1, j+1, &isbad);
 
-                if (!isbad && irplib_isnan(value) == 0 &&
+                if (!isbad &&
                     (first || value > *ppeak)) {
                     first = CPL_FALSE;
                     *ppeak = value;
@@ -1020,7 +916,7 @@ cpl_error_code irplib_gaussian_maxpos(const cpl_image * self,
     const cpl_size  nx = cpl_image_get_size_x(self);
     const cpl_size  ny = cpl_image_get_size_y(self);
     int             iretry = 3; /* Number retries with decreasing sigma */
-    int             ifluxapert;
+    int             ifluxapert = 0;
     double          med_dist;
     const double    median = cpl_image_get_median_dev(self, &med_dist);
     cpl_mask      * selection;
@@ -1038,7 +934,7 @@ cpl_error_code irplib_gaussian_maxpos(const cpl_image * self,
 #endif
     cpl_array     * gauss_parameters = NULL;
     cpl_errorstate  prestate = cpl_errorstate_get();
-    cpl_error_code  code;
+    cpl_error_code  code = CPL_ERROR_NONE;
 
 
     cpl_ensure_code( sigma > 0.0, CPL_ERROR_ILLEGAL_INPUT);
@@ -1078,6 +974,12 @@ cpl_error_code irplib_gaussian_maxpos(const cpl_image * self,
     /* Find the aperture with the greatest flux */
     code = irplib_apertures_find_max_flux(aperts, &ifluxapert, 1);
 
+    if (code) {
+        cpl_apertures_delete(aperts);
+        cpl_image_delete(labels);
+        return cpl_error_set(cpl_func, CPL_ERROR_DATA_NOT_FOUND);
+    }
+
     npixobj = cpl_apertures_get_npix(aperts, ifluxapert);
     objradius = sqrt((double)npixobj * CPL_MATH_1_PI);
     /* Size is power of two for future noise filtering w. fft */
