@@ -80,6 +80,10 @@
 #define REF_LINES                "REF_LINES"            // CALIB
 #define LCAL                     "LCAL"                 // CALIB
 #define DET_IMG_WAVE             "DET_IMG_WAVE"
+
+/* kmos_gen_reflines */
+#define KMOS_GEN_REFLINES_RAW   "REFLINES_TXT"
+
 // kmo_illumination
 #define FLAT_SKY                 "FLAT_SKY"             // RAW
 #define ILLUM_CORR               "ILLUM_CORR"           // CALIB
@@ -227,6 +231,7 @@
 #define QC_ARC_AR_FWHM_MEAN      "ESO QC ARC AR FWHM MEAN"
 #define QC_ARC_AR_FWHM_STDEV     "ESO QC ARC AR FWHM STDEV"
 #define QC_ARC_AR_FWHM_95ILE     "ESO QC ARC AR FWHM 95%ILE"
+#define QC_ARC_AR_VSCALE         "ESO QC ARC AR VSCALE"
 #define QC_ARC_NE_POS_MEAN       "ESO QC ARC NE POS MEAN"
 #define QC_ARC_NE_POS_MAXDIFF    "ESO QC ARC NE POS MAXDIFF"
 #define QC_ARC_NE_POS_MAXDIFF_ID "ESO QC ARC NE POS MAXDIFF ID"
@@ -235,6 +240,7 @@
 #define QC_ARC_NE_FWHM_MEAN      "ESO QC ARC NE FWHM MEAN"
 #define QC_ARC_NE_FWHM_STDEV     "ESO QC ARC NE FWHM STDEV"
 #define QC_ARC_NE_FWHM_95ILE     "ESO QC ARC NE FWHM 95%ILE"
+#define QC_ARC_NE_VSCALE         "ESO QC ARC NE VSCALE"
 
 // kmo_illumination
 #define QC_SPAT_UNIF             "ESO QC SPAT UNIF"
@@ -298,11 +304,20 @@ cpl_propertylist*  kmo_dfs_load_primary_header(
                                        cpl_frameset *frameset,
                                        const char *category);
 
+cpl_propertylist * kmos_dfs_load_sub_header(
+        cpl_frame       *   frame,
+        int                 device,
+        int                 noise) ;
+
 cpl_propertylist*  kmo_dfs_load_sub_header(
                                        cpl_frameset *frameset,
                                        const char *category,
                                        int device,
                                        int noise);
+kmclipm_vector * kmos_dfs_load_vector(
+        cpl_frame       *   frame,
+        int                 device,
+        int                 noise) ;
 
 kmclipm_vector*    kmo_dfs_load_vector(cpl_frameset *frameset,
                                        const char *category,
@@ -369,6 +384,10 @@ cpl_image*         kmo_dfs_load_image_frame_window(
                                        int ury,
                                        int sat_mode,
                                        int *nr_sat);
+cpl_imagelist * kmos_dfs_load_cube(
+        cpl_frame   *   frame,
+        int             device,
+        int             noise) ;
 
 cpl_imagelist*     kmo_dfs_load_cube(cpl_frameset *frameset,
                                        const char *category,
