@@ -1,5 +1,4 @@
-/* $Id: kmo_priv_combine-test.c,v 1.7 2013-10-08 11:19:14 aagudo Exp $
- *
+/*
  * This file is part of the KMOS Library
  * Copyright (C) 2007-2008 European Southern Observatory
  *
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
-/*
- * $Author: aagudo $
- * $Date: 2013-10-08 11:19:14 $
- * $Revision: 1.7 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -36,20 +28,24 @@
 #include "kmo_priv_combine.h"
 #include "kmo_utils.h"
 
+/*----------------------------------------------------------------------------*/
 /**
     @defgroup kmo_priv_combine_test   kmo_priv_combine unit tests
-
-    @{
 */
+/*----------------------------------------------------------------------------*/
+
+/**@{*/
 
 void kmo_test_verbose_off();
 void kmo_test_verbose_on();
 void kmo_test_fill_cube(cpl_imagelist *cube, float seed, float offset);
 void kmo_test_alloc_cube(cpl_imagelist *cube, int x, int y, int z);
 
+/*----------------------------------------------------------------------------*/
 /**
  * @brief   Test for kmo_align_subpix()
  */
+/*----------------------------------------------------------------------------*/
 void test_kmo_align_subpix()
 {
     double              xshift          = 0.1,
@@ -72,12 +68,8 @@ void test_kmo_align_subpix()
     kmo_test_verbose_off();
 
     // empty header_data
-    kmo_align_subpix(&xshift, &yshift,
-                           &data, NULL,
-                           &header_data, NULL,
-                           0, "BCS", BCS_NATURAL, tol, fid,
-                           &xmin, &xmax,
-                           &ymin, &ymax, "gaga");
+    kmo_align_subpix(&xshift, &yshift, &data, NULL, &header_data, NULL, 0, 
+            "BCS", BCS_NATURAL, tol, fid, &xmin, &xmax, &ymin, &ymax, "gaga");
     cpl_test_error(CPL_ERROR_DATA_NOT_FOUND);
 
     kmo_test_verbose_on();
@@ -105,12 +97,20 @@ void test_kmo_align_subpix()
     cpl_propertylist_append_string(header_data, "ESO PRO FRNAME", "ga");
     cpl_propertylist_append_int(header_data, "ESO PRO IFUNR", 1);
 
-    kmo_align_subpix(&xshift, &yshift,
-                           &data, NULL,
-                           &header_data, NULL,
-                           0, "BCS", BCS_NATURAL, tol, fid,
-                           &xmin, &xmax,
-                           &ymin, &ymax, "gaga");
+    /* CDN_M Matrix needs to be specified - PIPE-5106 PIPE-5115 */
+    /* If not specified, cpl_wcs() fails  */
+    cpl_propertylist_append_double(header_data, CD1_1, -5.55555e-5);
+    cpl_propertylist_append_double(header_data, CD1_2, 0);
+    cpl_propertylist_append_double(header_data, CD1_3, 0);
+    cpl_propertylist_append_double(header_data, CD2_1, 0);
+    cpl_propertylist_append_double(header_data, CD2_2, -5.55555e-5);
+    cpl_propertylist_append_double(header_data, CD2_3, 0);
+    cpl_propertylist_append_double(header_data, CD3_1, 0);
+    cpl_propertylist_append_double(header_data, CD3_2, 0);
+    cpl_propertylist_append_double(header_data, CD3_3, 0.0002075);
+
+    kmo_align_subpix(&xshift, &yshift, &data, NULL, &header_data, NULL, 0, 
+            "BCS", BCS_NATURAL, tol, fid, &xmin, &xmax, &ymin, &ymax, "gaga");
     cpl_test_error(CPL_ERROR_NONE);
     cpl_test_eq(xmin, 0);
     cpl_test_eq(ymin, 0);
@@ -122,12 +122,9 @@ void test_kmo_align_subpix()
     // with noise (empty)
     noise = cpl_imagelist_new();
     header_noise = cpl_propertylist_new();
-    kmo_align_subpix(&xshift, &yshift,
-                           &data, &noise,
-                           &header_data, &header_noise,
-                           0, "BCS", BCS_NATURAL, tol, fid,
-                           &xmin, &xmax,
-                           &ymin, &ymax, "gaga");
+    kmo_align_subpix(&xshift, &yshift, &data, &noise, &header_data, 
+            &header_noise, 0, "BCS", BCS_NATURAL, tol, fid, &xmin, &xmax,
+            &ymin, &ymax, "gaga");
     cpl_test_error(CPL_ERROR_NONE);
     cpl_test_eq(xmin, 0);
     cpl_test_eq(ymin, 0);
@@ -140,12 +137,9 @@ void test_kmo_align_subpix()
     kmo_test_alloc_cube(noise, 14, 14, 10);
     kmo_test_fill_cube(noise, 0.0, 0.1);
 
-    kmo_align_subpix(&xshift, &yshift,
-                           &data, &noise,
-                           &header_data, &header_noise,
-                           0, "BCS", BCS_NATURAL, tol, fid,
-                           &xmin, &xmax,
-                           &ymin, &ymax, "gaga");
+    kmo_align_subpix(&xshift, &yshift, &data, &noise, &header_data, 
+            &header_noise, 0, "BCS", BCS_NATURAL, tol, fid, &xmin, &xmax, 
+            &ymin, &ymax, "gaga");
     cpl_test_error(CPL_ERROR_NONE);
     cpl_test_eq(xmin, 0);
     cpl_test_eq(ymin, 0);
@@ -163,9 +157,11 @@ void test_kmo_align_subpix()
     cpl_test_error(CPL_ERROR_NONE);
 }
 
+/*----------------------------------------------------------------------------*/
 /**
  * @brief   Test for kmo_priv_combine()
  */
+/*----------------------------------------------------------------------------*/
 void test_kmo_priv_combine()
 {
     int                 nr_frames       = 3;
@@ -189,14 +185,9 @@ void test_kmo_priv_combine()
     kmo_test_verbose_off();
 
     // empty header_data
-    kmo_priv_combine(data, NULL,
-                           header_data, NULL,
-                           nr_frames, 0,
-                           "obj_bla", "",
-                           "header", "BCS", "gauss", "shifts2.txt",
-                           "ksigma",
-                            3.0, 3.0, 3, 5, 5, BCS_NATURAL, TRUE,
-                            &data_out, &noise_out, NULL);
+    kmo_priv_combine(data, NULL, header_data, NULL, nr_frames, 0, "obj_bla", 
+            "", "header", "BCS", "gauss", "shifts2.txt", "ksigma", 3.0, 3.0, 
+            3, 5, 5, BCS_NATURAL, TRUE, &data_out, &noise_out, NULL);
     cpl_test_error(CPL_ERROR_DATA_NOT_FOUND);
 
     // add CD-matrix to header_data
@@ -213,14 +204,9 @@ void test_kmo_priv_combine()
         cpl_propertylist_append_string(header_data[i], "ESO PRO FRNAME", "ga");
         cpl_propertylist_append_int(header_data[i], "ESO PRO IFUNR", i+1);
     }
-    kmo_priv_combine(data, NULL,
-                           header_data, NULL,
-                           nr_frames, 0,
-                           "obj_bla", "",
-                           "header", "BCS", "gauss", "shifts2.txt",
-                           "ksigma",
-                            3.0, 3.0, 3, 5, 5, BCS_NATURAL, TRUE,
-                            &data_out,&noise_out, NULL);
+    kmo_priv_combine(data, NULL, header_data, NULL, nr_frames, 0, "obj_bla", 
+            "", "header", "BCS", "gauss", "shifts2.txt", "ksigma", 3.0, 3.0, 
+            3, 5, 5, BCS_NATURAL, TRUE, &data_out,&noise_out, NULL);
     cpl_test_error(CPL_ERROR_UNSPECIFIED);
 
 //    kmo_test_verbose_on();
@@ -255,14 +241,10 @@ void test_kmo_priv_combine()
     cpl_propertylist_append_double(header_data[2], CRVAL1, 6.125);
     cpl_propertylist_append_double(header_data[2], CRVAL2, -72.078);
     cpl_propertylist_append_double(header_data[2], CRVAL3, 1.43099);
-    kmo_priv_combine(data, NULL,
-                           header_data, NULL,
-                           nr_frames, 0,
-                           "obj_bla", "",
-                           "header", "BCS", "gauss", "shifts2.txt",
-                           "ksigma",
-                            3.0, 3.0, 3, 5, 5, BCS_NATURAL, TRUE,
-                            &data_out,&noise_out, NULL);
+
+    kmo_priv_combine(data, NULL, header_data, NULL, nr_frames, 0, "obj_bla", 
+            "", "header", "BCS", "gauss", "shifts2.txt", "ksigma", 3.0, 3.0, 
+            3, 5, 5, BCS_NATURAL, TRUE, &data_out,&noise_out, NULL);
     cpl_test_error(CPL_ERROR_NONE);
     cpl_test_abs(kmo_imagelist_get_mean(data_out), 11.3376, 0.01);
     cpl_test_abs(kmo_imagelist_get_mean(noise_out), 0, 0.01);
@@ -320,14 +302,10 @@ void test_kmo_priv_combine()
     cpl_propertylist_append_double(header_data[2], CRVAL1, 6.125);
     cpl_propertylist_append_double(header_data[2], CRVAL2, -72.078);
     cpl_propertylist_append_double(header_data[2], CRVAL3, 1.43099);
-    kmo_priv_combine(data, noise,
-                           header_data, NULL,
-                           nr_frames, 0,
-                           "obj_bla", "",
-                           "header", "BCS", "gauss", "shifts2.txt",
-                           "ksigma",
-                            3.0, 3.0, 3, 5, 5, BCS_NATURAL, TRUE,
-                            &data_out,&noise_out, NULL);
+
+    kmo_priv_combine(data, noise, header_data, NULL, nr_frames, 0, "obj_bla", 
+            "", "header", "BCS", "gauss", "shifts2.txt", "ksigma", 3.0, 3.0, 
+            3, 5, 5, BCS_NATURAL, TRUE, &data_out,&noise_out, NULL);
     cpl_test_error(CPL_ERROR_NONE);
     cpl_test_abs(kmo_imagelist_get_mean(data_out), 11.3376, 0.01);
     cpl_test_abs(kmo_imagelist_get_mean(noise_out), 0, 0.01);
@@ -389,14 +367,10 @@ void test_kmo_priv_combine()
     header_noise[0] = cpl_propertylist_duplicate(header_data[0]);
     header_noise[1] = cpl_propertylist_duplicate(header_data[1]);
     header_noise[2] = cpl_propertylist_duplicate(header_data[2]);
-    kmo_priv_combine(data, noise,
-                           header_data, header_noise,
-                           nr_frames, nr_frames,
-                           "obj_bla", "",
-                           "header", "BCS", "gauss", "shifts2.txt",
-                           "ksigma",
-                            3.0, 3.0, 3, 5, 5, BCS_NATURAL, TRUE,
-                            &data_out,&noise_out, NULL);
+    kmo_priv_combine(data, noise, header_data, header_noise, nr_frames, 
+            nr_frames, "obj_bla", "", "header", "BCS", "gauss", "shifts2.txt", 
+            "ksigma", 3.0, 3.0, 3, 5, 5, BCS_NATURAL, TRUE, &data_out,
+            &noise_out, NULL);
     cpl_test_error(CPL_ERROR_NONE);
     cpl_test_abs(kmo_imagelist_get_mean(data_out), 11.3376, 0.01);
     cpl_test_abs(kmo_imagelist_get_mean(noise_out), 0, 0.01);
@@ -419,16 +393,16 @@ void test_kmo_priv_combine()
     kmo_test_verbose_on();
 }
 
+/*----------------------------------------------------------------------------*/
 /**
     @brief   Test of helper functions for kmo_combine
 */
+/*----------------------------------------------------------------------------*/
 int main()
 {
-    cpl_test_init("<kmos-spark@mpe.mpg.de>", CPL_MSG_WARNING);
-
+    cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
     test_kmo_align_subpix();
     test_kmo_priv_combine();
-
     return cpl_test_end(0);
 }
 
