@@ -1,5 +1,4 @@
-/* $Id: kmo_combine.c,v 1.32 2013-06-27 13:10:21 aagudo Exp $
- *
+/* 
  * This file is part of the KMOS Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
  *
@@ -18,13 +17,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-/*
- * $Author: aagudo $
- * $Date: 2013-06-27 13:10:21 $
- * $Revision: 1.32 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -232,7 +224,7 @@ int cpl_plugin_get_info(cpl_pluginlist *list)
                         "Combine reconstructed cubes",
                         kmo_combine_description,
                         "Alex Agudo Berbel",
-                        "kmos-spark@mpe.mpg.de",
+                        "usd-help@eso.org",
                         kmos_get_license(),
                         kmo_combine_create,
                         kmo_combine_exec,
@@ -362,7 +354,7 @@ static int kmo_combine_create(cpl_plugin *plugin)
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
     cpl_parameterlist_append(recipe->parameters, p);
 
-    return kmo_combine_pars_create(recipe->parameters,
+    return kmos_combine_pars_create(recipe->parameters,
                                    "kmos.kmo_combine",
                                    DEF_REJ_METHOD,
                                    FALSE);
@@ -587,7 +579,7 @@ static int kmo_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
             kmo_dfs_print_parameter_help(parlist, "kmos.kmo_combine.name"));
 
         KMO_TRY_EXIT_IF_ERROR(
-            kmo_combine_pars_load(parlist,
+            kmos_combine_pars_load(parlist,
                                   "kmos.kmo_combine",
                                   &cmethod,
                                   &cpos_rej,
@@ -714,6 +706,15 @@ static int kmo_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
             } else {
                 if (ifus != NULL) {
                     char *tmptmp = NULL;
+
+                    // replace all ; with _
+                    char *found_char = NULL;
+                    found_char = strstr(ifus_txt, ";");
+                    while (found_char != NULL) {
+                        strncpy(found_char, "_", 1);
+                        found_char = strstr(ifus_txt, ";");
+                    }
+
                     if (strlen(ifus_txt) > 10) {
                         KMO_TRY_EXIT_IF_NULL(
                             tmptmp = kmo_shorten_ifu_string(ifus_txt));
@@ -736,7 +737,7 @@ static int kmo_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
         //
         // load all data (and noise if existent) cubes and store them
         //
-        for (nv = 0; nv < name_vec_size; nv++){
+        for (nv = 0; nv < name_vec_size; nv++) {
             name = name_vec[nv];
 
             data_cube_counter = 0;
@@ -971,7 +972,7 @@ static int kmo_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
                     fn_mask = cpl_sprintf("%s_%d", EXP_MASK, suppress_index++));
             }
 
-            frame = cpl_frameset_get_first(frameset);
+            frame = cpl_frameset_find(frameset, NULL);
             KMO_TRY_EXIT_IF_ERROR(
                 kmo_dfs_save_main_header(frameset, fn_combine, "", frame, NULL, parlist, cpl_func));
             KMO_TRY_EXIT_IF_ERROR(
@@ -991,6 +992,16 @@ static int kmo_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
                 kmo_dfs_save_cube(cube_combined_data, fn_combine, "", data_header_list[0], 0./0.));
             KMO_TRY_EXIT_IF_ERROR(
                 kmo_dfs_save_cube(cube_combined_noise, fn_combine, "", noise_header_list[0], 0./0.));
+            cpl_propertylist_erase(data_header_list[0], CRPIX3);
+            cpl_propertylist_erase(data_header_list[0], CRPIX3);
+            cpl_propertylist_erase(data_header_list[0], CRVAL3);
+            cpl_propertylist_erase(data_header_list[0], CDELT3);
+            cpl_propertylist_erase(data_header_list[0], CD1_3);
+            cpl_propertylist_erase(data_header_list[0], CD2_3);
+            cpl_propertylist_erase(data_header_list[0], CD3_1);
+            cpl_propertylist_erase(data_header_list[0], CD3_2);
+            cpl_propertylist_erase(data_header_list[0], CD3_3);
+            cpl_propertylist_erase(data_header_list[0], CTYPE3);
             KMO_TRY_EXIT_IF_ERROR(
                 kmo_dfs_save_image(exp_mask, fn_mask, "", data_header_list[0], 0./0.));
 
@@ -1022,7 +1033,7 @@ static int kmo_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
             }
             cpl_free(fn_combine); fn_combine = NULL;
             cpl_free(fn_mask); fn_mask = NULL;
-        }
+        } // end for (nv = 0; nv < name_vec_size; nv++)
     }
     KMO_CATCH
     {
