@@ -1,5 +1,4 @@
-/* $Id: kmo_extract_spec.c,v 1.15 2013-06-07 15:41:20 aagudo Exp $
- *
+/*
  * This file is part of the KMOS Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
  *
@@ -18,13 +17,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-/*
- * $Author: aagudo $
- * $Date: 2013-06-07 15:41:20 $
- * $Revision: 1.15 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -193,7 +185,7 @@ int cpl_plugin_get_info(cpl_pluginlist *list)
                         "Extract a spectrum from a cube.",
                         kmo_extract_spec_description,
                         "Alex Agudo Berbel",
-                        "kmos-spark@mpe.mpg.de",
+                        "usd-help@eso.org",
                         kmos_get_license(),
                         kmo_extract_spec_create,
                         kmo_extract_spec_exec,
@@ -267,7 +259,7 @@ static int kmo_extract_spec_create(cpl_plugin *plugin)
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
     cpl_parameterlist_append(recipe->parameters, p);
 
-    return kmo_combine_pars_create(recipe->parameters,
+    return kmos_combine_pars_create(recipe->parameters,
                                    "kmos.kmo_extract_spec",
                                    DEF_REJ_METHOD,
                                    FALSE);
@@ -496,7 +488,7 @@ static int kmo_extract_spec(cpl_parameterlist *parlist, cpl_frameset *frameset)
 
         } else if (strcmp(mask_method, "optimal") == 0) {
             KMO_TRY_EXIT_IF_ERROR(
-                kmo_combine_pars_load(parlist,
+                kmos_combine_pars_load(parlist,
                                       "kmos.kmo_extract_spec",
                                       &cmethod,
                                       &cpos_rej,
@@ -700,23 +692,23 @@ static int kmo_extract_spec(cpl_parameterlist *parlist, cpl_frameset *frameset)
                 if (save_mask) {
                     // delete WCS for 3rd dimension since mask is 2D
                     KMO_TRY_EXIT_IF_ERROR(
-                        cpl_propertylist_erase(sub_header_data, CRPIX3));
+                        cpl_propertylist_erase(sub_header_mask, CRPIX3));
                     KMO_TRY_EXIT_IF_ERROR(
-                        cpl_propertylist_erase(sub_header_data, CRVAL3));
+                        cpl_propertylist_erase(sub_header_mask, CRVAL3));
                     KMO_TRY_EXIT_IF_ERROR(
-                        cpl_propertylist_erase(sub_header_data, CDELT3));
+                        cpl_propertylist_erase(sub_header_mask, CDELT3));
                     KMO_TRY_EXIT_IF_ERROR(
-                        cpl_propertylist_erase(sub_header_data, CTYPE3));
+                        cpl_propertylist_erase(sub_header_mask, CTYPE3));
                     KMO_TRY_EXIT_IF_ERROR(
-                        cpl_propertylist_erase(sub_header_data, CD1_3));
+                        cpl_propertylist_erase(sub_header_mask, CD1_3));
                     KMO_TRY_EXIT_IF_ERROR(
-                        cpl_propertylist_erase(sub_header_data, CD2_3));
+                        cpl_propertylist_erase(sub_header_mask, CD2_3));
                     KMO_TRY_EXIT_IF_ERROR(
-                        cpl_propertylist_erase(sub_header_data, CD3_3));
+                        cpl_propertylist_erase(sub_header_mask, CD3_3));
                     KMO_TRY_EXIT_IF_ERROR(
-                        cpl_propertylist_erase(sub_header_data, CD3_1));
+                        cpl_propertylist_erase(sub_header_mask, CD3_1));
                     KMO_TRY_EXIT_IF_ERROR(
-                        cpl_propertylist_erase(sub_header_data, CD3_2));
+                        cpl_propertylist_erase(sub_header_mask, CD3_2));
 
                     KMO_TRY_EXIT_IF_ERROR(
                         kmo_dfs_save_image(mask, EXTRACT_SPEC_MASK, "",
