@@ -1,5 +1,4 @@
-/* $Id: kmo_fit_profile.c,v 1.10 2013-06-07 15:41:21 aagudo Exp $
- *
+/*
  * This file is part of the KMOS Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
  *
@@ -18,13 +17,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-/*
- * $Author: aagudo $
- * $Date: 2013-06-07 15:41:21 $
- * $Revision: 1.10 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -138,7 +130,7 @@ int cpl_plugin_get_info(cpl_pluginlist *list)
                         "resolution or find the centre of a source",
                         kmo_fit_profile_description,
                         "Alex Agudo Berbel",
-                        "kmos-spark@mpe.mpg.de",
+                        "usd-help@eso.org",
                         kmos_get_license(),
                         kmo_fit_profile_create,
                         kmo_fit_profile_exec,
