@@ -1,5 +1,4 @@
-/* $Id: kmo_reconstruct.c,v 1.61 2013/10/08 14:55:01 erw Exp $
- *
+/*
  * This file is part of the KMOS Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
  *
@@ -18,13 +17,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-/*
- * $Author: erw $
- * $Date: 2013/10/08 14:55:01 $
- * $Revision: 1.61 $
- * $Name:  $
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -64,9 +56,9 @@ static int kmo_reconstruct(cpl_parameterlist *, cpl_frameset *);
  *----------------------------------------------------------------------------*/
 
 static char kmo_reconstruct_description[] =
-"Data with or without noise is reconstructed into a cube using the calibration\n"
-"frames XCAL, YCAL and LCAL. XCAL and YCAL are generated using recipe kmo_flat,\n"
-"LCAL is generated using recipe kmo_wave_cal.\n"
+"Data with or without noise is reconstructed into a cube using the\n"
+"calibration frames XCAL, YCAL and LCAL. XCAL and YCAL are generated using\n"
+"recipe kmo_flat, LCAL is generated using recipe kmo_wave_cal.\n"
 "The input data can contain noise extensions and will be reconstructed into\n"
 "additional extensions.\n"
 "If an OH spectrum is given in the SOF file the lambda axis will be corrected\n"
@@ -78,10 +70,10 @@ static char kmo_reconstruct_description[] =
 "The interpolation method used for reconstruction.\n"
 "\n"
 "--detectorimage\n"
-"Specify if the resampled image of the input frame should be generated. There-\n"
-"fore all slitlets of all IFUs are aligned one next to the other. This frame\n"
-"serves for quality control. One can immediately see if the reconstruction was\n"
-"successful.\n"
+"Specify if the resampled image of the input frame should be generated.\n"
+"Therefore all slitlets of all IFUs are aligned one next to the other. This\n"
+"frame serves for quality control. One can immediately see if the\n"
+"reconstruction was successful.\n"
 "\n"
 "--file_extension"
 "Set to TRUE if OBS_ID (from input frame header) should be appended to the\n"
@@ -96,8 +88,8 @@ static char kmo_reconstruct_description[] =
 "Defines the range to search for neighbors during reconstruction\n"
 "\n"
 "--b_samples\n"
-"The number of samples in spectral direction for the reconstructed cube. Ideal-\n"
-"ly this number should be greater than 2048, the detector size.\n"
+"The number of samples in spectral direction for the reconstructed cube."
+"Ideally this number should be greater than 2048, the detector size.\n"
 "\n"
 "--b_start\n"
 "--b_end\n"
@@ -113,50 +105,51 @@ static char kmo_reconstruct_description[] =
 "closest rotator angles in the calibration file. Otherwise take the values\n"
 "of the closest rotator angle\n"
 "\n"
-"-------------------------------------------------------------------------------\n"
+"---------------------------------------------------------------------------\n"
 "  Input files:\n"
 "\n"
-"   DO                  KMOS                                                    \n"
-"   category            Type     Explanation                    Required #Frames\n"
-"   --------            -----    -----------                    -------- -------\n"
-"   DARK    or          RAW/F2D  data with                          Y       1   \n"
-"   FLAT_ON or          RAW/F2D  or without noise                               \n"
-"   ARC_ON  or          RAW/F2D                                                 \n"
-"   OBJECT  or          RAW                                                     \n"
-"   STD     or          RAW                                                     \n"
-"   SCIENCE             RAW                                                     \n"
-"   XCAL                F2D      x-direction calib. frame           Y       1   \n"
-"   YCAL                F2D      y-direction calib. frame           Y       1   \n"
-"   LCAL                F2D      Wavelength calib. frame            Y       1   \n"
-"   WAVE_BAND           F2L      Table with start-/end-wavelengths  Y       1   \n"
-"   OH_SPEC             F1S      Vector holding OH lines            N       1   \n"
+"   DO              KMOS                                                    \n"
+"   category        Type     Explanation                    Required #Frames\n"
+"   --------        -----    -----------                    -------- -------\n"
+"   DARK    or      RAW/F2D  data with                          Y       1   \n"
+"   FLAT_ON or      RAW/F2D  or without noise                               \n"
+"   ARC_ON  or      RAW/F2D                                                 \n"
+"   OBJECT  or      RAW                                                     \n"
+"   STD     or      RAW                                                     \n"
+"   SCIENCE         RAW                                                     \n"
+"   XCAL            F2D      x-direction calib. frame           Y       1   \n"
+"   YCAL            F2D      y-direction calib. frame           Y       1   \n"
+"   LCAL            F2D      Wavelength calib. frame            Y       1   \n"
+"   WAVE_BAND       F2L      Table with start-/end-wavelengths  Y       1   \n"
+"   OH_SPEC         F1S      Vector holding OH lines            N       1   \n"
 "\n"
 "  Output files:\n"
 "\n"
-"   DO                    KMOS\n"
-"   category              Type     Explanation\n"
+"   DO                KMOS\n"
+"   category          Type     Explanation\n"
 "   --------              -----    -----------\n"
-"   CUBE_DARK   or        F3I      Reconstructed cube   \n"
-"   CUBE_FLAT   or        RAW/F2D  with or without noise\n"
-"   CUBE_ARC    or                                      \n"
-"   CUBE_OBJECT or                                      \n"
-"   CUBE_STD    or                                      \n"
-"   CUBE_SCIENCE                                        \n"
-"-------------------------------------------------------------------------------\n"
+"   CUBE_DARK   or    F3I      Reconstructed cube   \n"
+"   CUBE_FLAT   or    RAW/F2D  with or without noise\n"
+"   CUBE_ARC    or                                  \n"
+"   CUBE_OBJECT or                                  \n"
+"   CUBE_STD    or                                  \n"
+"   CUBE_SCIENCE                                    \n"
+"---------------------------------------------------------------------------\n"
 "\n";
 
 /*-----------------------------------------------------------------------------
  *                              Functions code
  *----------------------------------------------------------------------------*/
 
+/*----------------------------------------------------------------------------*/
 /**
- * @defgroup kmo_reconstruct kmo_reconstruct Performs the cube reconstruction
- *
- * See recipe description for details.
+ * @defgroup kmo_reconstruct    Performs the cube reconstruction
  */
+/*----------------------------------------------------------------------------*/
 
 /**@{*/
 
+/*----------------------------------------------------------------------------*/
 /**
   @brief    Build the list of available plugins, for this module. 
   @param    list    the plugin list
@@ -165,6 +158,7 @@ static char kmo_reconstruct_description[] =
   Create the recipe instance and make it available to the application using the 
   interface. This function is exported.
  */
+/*----------------------------------------------------------------------------*/
 int cpl_plugin_get_info(cpl_pluginlist *list)
 {
     cpl_recipe *recipe = cpl_calloc(1, sizeof *recipe);
@@ -179,7 +173,7 @@ int cpl_plugin_get_info(cpl_pluginlist *list)
                         "using different interpolation methods.",
                         kmo_reconstruct_description,
                         "Alex Agudo Berbel",
-                        "kmos-spark@mpe.mpg.de",
+                        "usd-help@eso.org",
                         kmos_get_license(),
                         kmo_reconstruct_create,
                         kmo_reconstruct_exec,
@@ -190,6 +184,7 @@ int cpl_plugin_get_info(cpl_pluginlist *list)
     return 0;
 }
 
+/*----------------------------------------------------------------------------*/
 /**
   @brief    Setup the recipe options    
   @param    plugin  the plugin
@@ -197,6 +192,7 @@ int cpl_plugin_get_info(cpl_pluginlist *list)
 
   Defining the command-line/configuration parameters for the recipe.
  */
+/*----------------------------------------------------------------------------*/
 static int kmo_reconstruct_create(cpl_plugin *plugin)
 {
     cpl_recipe *recipe;
@@ -213,111 +209,86 @@ static int kmo_reconstruct_create(cpl_plugin *plugin)
 
     /* Fill the parameters list */
     /* --imethod */
-    p = cpl_parameter_new_value("kmos.kmo_reconstruct.imethod",
-                                CPL_TYPE_STRING,
-                                "Method to use for interpolation. "
-                                "[\"NN\" (nearest neighbour), "
-                                "\"lwNN\" (linear weighted nearest neighbor), "
-                                "\"swNN\" (square weighted nearest neighbor), "
-                                "\"MS\" (Modified Shepard's method)"
-                                "\"CS\" (Cubic spline)]",
-                                "kmos.kmo_reconstruct",
-                                "CS");
+    p = cpl_parameter_new_value("kmos.kmo_reconstruct.imethod", CPL_TYPE_STRING,
+            "Method to use for interpolation. [\"NN\" (nearest neighbour), "
+            "\"lwNN\" (linear weighted nearest neighbor), "
+            "\"swNN\" (square weighted nearest neighbor), "
+            "\"MS\" (Modified Shepard's method)"
+            "\"CS\" (Cubic spline)]",
+            "kmos.kmo_reconstruct", "CS");
     cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "imethod");
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
     cpl_parameterlist_append(recipe->parameters, p);
 
     /* --neighborhoodRange */
     p = cpl_parameter_new_value("kmos.kmo_reconstruct.neighborhoodRange",
-                                CPL_TYPE_DOUBLE,
-                                "Defines the range to search for neighbors. "
-                                "in pixels",
-                                "kmos.kmo_reconstruct",
-                                1.001);
+            CPL_TYPE_DOUBLE,
+            "Defines the range to search for neighbors. in pixels",
+            "kmos.kmo_reconstruct", 1.001);
     cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "neighborhoodRange");
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
     cpl_parameterlist_append(recipe->parameters, p);
 
     /* --flux */
-    p = cpl_parameter_new_value("kmos.kmo_reconstruct.flux",
-                                CPL_TYPE_BOOL,
-                                "TRUE: Apply flux conservation. FALSE: otherwise",
-                                "kmos.kmo_reconstruct",
-                                FALSE);
+    p = cpl_parameter_new_value("kmos.kmo_reconstruct.flux", CPL_TYPE_BOOL,
+            "TRUE: Apply flux conservation. FALSE: otherwise",
+            "kmos.kmo_reconstruct", FALSE);
     cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "flux");
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
     cpl_parameterlist_append(recipe->parameters, p);
 
     /* --detectorimage */
     p = cpl_parameter_new_value("kmos.kmo_reconstruct.detectorimage",
-                                CPL_TYPE_BOOL,
-                                "TRUE: if resampled detector frame should be "
-                                "created, FALSE: otherwise",
-                                "kmos.kmo_reconstruct",
-                                FALSE);
+            CPL_TYPE_BOOL,
+            "TRUE: if resampled detector frame should be "
+            "created, FALSE: otherwise",
+            "kmos.kmo_reconstruct", FALSE);
     cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "detimg");
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
     cpl_parameterlist_append(recipe->parameters, p);
 
     /* --file_extension */
     p = cpl_parameter_new_value("kmos.kmo_reconstruct.file_extension",
-                                CPL_TYPE_BOOL,
-                                "TRUE: if OBS_ID keyword should be appended to "
-                                "output frames, FALSE: otherwise",
-                                "kmos.kmo_reconstruct",
-                                FALSE);
+            CPL_TYPE_BOOL,
+            "TRUE: if OBS_ID keyword should be appended to "
+            "output frames, FALSE: otherwise",
+            "kmos.kmo_reconstruct", FALSE);
     cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "file_extension");
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
     cpl_parameterlist_append(recipe->parameters, p);
 
     /* --pix_scale */
     p = cpl_parameter_new_value("kmos.kmo_reconstruct.pix_scale",
-                                CPL_TYPE_DOUBLE,
-                                "Change the pixel scale [arcsec]. "
-                                "Default of 0.2\" results into cubes of 14x14pix, "
-                                "a scale of 0.1\" results into cubes of 28x28pix, "
-                                "etc.",
-                                "kmos.kmo_reconstruct",
-                                KMOS_PIX_RESOLUTION);
+            CPL_TYPE_DOUBLE,
+            "Change the pixel scale [arcsec]. "
+            "Default of 0.2\" results into cubes of 14x14pix, "
+            "a scale of 0.1\" results into cubes of 28x28pix, etc.",
+            "kmos.kmo_reconstruct", KMOS_PIX_RESOLUTION);
     cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "pix_scale");
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
     cpl_parameterlist_append(recipe->parameters, p);
 
-    /* --dev_flip */
-    p = cpl_parameter_new_value("kmos.kmo_reconstruct.dev_flip",
-                                CPL_TYPE_BOOL,
-                                "INTENDED FOR PIPELINE DEVELOPERS ONLY: "
-                                "Set this parameter to TRUE if the wavelengths "
-                                "are ascending on the detector from bottom to "
-                                "top (only for old simulation data).",
-                                "kmos.kmo_reconstruct",
-                                FALSE);
-    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "dev_flip");
-    cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
-    cpl_parameterlist_append(recipe->parameters, p);
-
     /* --xcal_interpolation */
     p = cpl_parameter_new_value("kmos.kmo_reconstruct.xcal_interpolation",
-                                CPL_TYPE_BOOL,
-                                "TRUE: Interpolate xcal between rotator angles. FALSE: otherwise",
-                                "kmos.kmo_reconstruct",
-                                TRUE);
+            CPL_TYPE_BOOL,
+            "TRUE: Interpolate xcal between rotator angles. FALSE: otherwise",
+            "kmos.kmo_reconstruct", TRUE);
     cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "xcal_interpolation");
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
     cpl_parameterlist_append(recipe->parameters, p);
 
-    // add parameters for band-definition
-    kmo_band_pars_create(recipe->parameters,
-                         "kmos.kmo_reconstruct");
-
+    /* Add parameters for band-definition */
+    kmos_band_pars_create(recipe->parameters, "kmos.kmo_reconstruct");
     return 0;
 }
 
+/*----------------------------------------------------------------------------*/
 /**
   @brief    Execute the plugin instance given by the interface
   @param    plugin  the plugin
   @return   0 if everything is ok
  */
+/*----------------------------------------------------------------------------*/
 static int kmo_reconstruct_exec(cpl_plugin *plugin)
 {
     cpl_recipe  *recipe;
@@ -330,11 +301,13 @@ static int kmo_reconstruct_exec(cpl_plugin *plugin)
     return kmo_reconstruct(recipe->parameters, recipe->frames);
 }
 
+/*----------------------------------------------------------------------------*/
 /**
   @brief    Destroy what has been created by the 'create' function
   @param    plugin  the plugin
   @return   0 if everything is ok
  */
+/*----------------------------------------------------------------------------*/
 static int kmo_reconstruct_destroy(cpl_plugin *plugin)
 {
     cpl_recipe *recipe;
@@ -348,6 +321,7 @@ static int kmo_reconstruct_destroy(cpl_plugin *plugin)
     return 0 ;
 }
 
+/*----------------------------------------------------------------------------*/
 /**
   @brief    Interpret the command line options and execute the data processing
   @param    parlist     the parameters list
@@ -362,6 +336,7 @@ static int kmo_reconstruct_destroy(cpl_plugin *plugin)
     @li CPL_ERROR_INCOMPATIBLE_INPUT if the dimensions of the two operands
                                      do not match
  */
+/*----------------------------------------------------------------------------*/
 static int kmo_reconstruct(cpl_parameterlist *parlist, cpl_frameset *frameset)
 {
     int                 ret_val                 = 0,
@@ -376,7 +351,6 @@ static int kmo_reconstruct(cpl_parameterlist *parlist, cpl_frameset *frameset)
                         ifu_nr                  = 0,
                         obs_id                  = 0,
                         file_extension          = FALSE,
-                        dev_flip                = FALSE,
                         xcal_interpolation      = FALSE,
                         detImgCube              = FALSE,
                         l = 0, x = 0, y = 0;
@@ -525,7 +499,7 @@ static int kmo_reconstruct(cpl_parameterlist *parlist, cpl_frameset *frameset)
             kmo_dfs_print_parameter_help(parlist,
                                      "kmos.kmo_reconstruct.neighborhoodRange"));
 
-        kmo_band_pars_load(parlist, "kmos.kmo_reconstruct");
+        kmos_band_pars_load(parlist, "kmos.kmo_reconstruct");
 
         file_extension = kmo_dfs_get_parameter_bool(parlist,
                                         "kmos.kmo_reconstruct.file_extension");
@@ -546,16 +520,6 @@ static int kmo_reconstruct(cpl_parameterlist *parlist, cpl_frameset *frameset)
                        "pix_scale must be between 0.01 and 0.4 (results in cubes "
                        "with 7x7 to 280x280 pixels)!");
 
-        dev_flip = kmo_dfs_get_parameter_bool(parlist,
-                                           "kmos.kmo_reconstruct.dev_flip");
-        KMO_TRY_CHECK_ERROR_STATE();
-        KMO_TRY_EXIT_IF_ERROR(
-            kmo_dfs_print_parameter_help(parlist, "kmos.kmo_reconstruct.dev_flip"));
-        KMO_TRY_ASSURE((dev_flip == TRUE) ||
-                       (dev_flip == FALSE),
-                       CPL_ERROR_ILLEGAL_INPUT,
-                       "dev_flip must be TRUE or FALSE!");
-
         xcal_interpolation = kmo_dfs_get_parameter_bool(parlist,
                                            "kmos.kmo_reconstruct.xcal_interpolation");
         KMO_TRY_CHECK_ERROR_STATE();
@@ -601,79 +565,16 @@ static int kmo_reconstruct(cpl_parameterlist *parlist, cpl_frameset *frameset)
             kmo_check_frame_setup(frameset, XCAL, LCAL,
                                        TRUE, FALSE, TRUE));
 
-        if (cpl_frameset_count_tags(frameset, DARK) != 1) {
+        if (cpl_frameset_count_tags(frameset, OH_SPEC) > 0) {
+            KMO_TRY_EXIT_IF_ERROR(kmo_check_oh_spec_setup(frameset, XCAL));
+        }
 
+        if (cpl_frameset_count_tags(frameset, DARK) != 1) {
             // check if filters, gratings and rotator offset match
             // (except for DARK frames)
             KMO_TRY_EXIT_IF_ERROR(
                 kmo_check_frame_setup(frameset, XCAL, input_frame_name,
                                            TRUE, FALSE, FALSE));
-/*
-            // check if rotator offset don't differ to much
-            cpl_frame        *f1 = NULL, *f2 = NULL;
-            cpl_propertylist *h1 = NULL, *h2 = NULL;
-            char             *kw = NULL;
-            double           tmp_dbl1 = 0.0, tmp_dbl2 = 0.0;
-
-            KMO_TRY_EXIT_IF_NULL(
-                f1 = kmo_dfs_get_frame(frameset, XCAL));
-
-            KMO_TRY_EXIT_IF_NULL(
-                f2 = kmo_dfs_get_frame(frameset, input_frame_name));
-            h1 = kmclipm_propertylist_load(cpl_frame_get_filename(f1), 0);
-            if (cpl_error_get_code() != CPL_ERROR_NONE) {
-                cpl_msg_error("","File not found: %s!",
-                              cpl_frame_get_filename(f1));
-                KMO_TRY_CHECK_ERROR_STATE();
-            }
-
-            h2 = kmclipm_propertylist_load(cpl_frame_get_filename(f2), 0);
-            if (cpl_error_get_code() != CPL_ERROR_NONE) {
-                cpl_msg_error("","File not found: %s!",
-                              cpl_frame_get_filename(f2));
-                KMO_TRY_CHECK_ERROR_STATE();
-            }
-            KMO_TRY_EXIT_IF_NULL(
-                kw = cpl_sprintf("%s", ROTANGLE));
-            tmp_dbl1 = cpl_propertylist_get_double(h1, kw);
-            if (cpl_error_get_code() != CPL_ERROR_NONE) {
-                KMO_TRY_ASSURE(1 == 0,
-                               CPL_ERROR_ILLEGAL_INPUT,
-                               "keyword \n%s\n of frame %s is missing!",
-                               keyword, XCAL);
-            }
-
-            tmp_dbl2 = cpl_propertylist_get_double(h2, kw);
-            if (cpl_error_get_code() != CPL_ERROR_NONE) {
-                KMO_TRY_ASSURE(1 == 0,
-                               CPL_ERROR_ILLEGAL_INPUT,
-                               "keyword \n%s\n of frame %s is missing!",
-                               keyword, input_frame_name);
-            }
-
-            // strip angles below 0 deg and above 360 deg
-            kmclipm_strip_angle(&tmp_dbl1);
-            kmclipm_strip_angle(&tmp_dbl2);
-
-            if (fabs(tmp_dbl1 - tmp_dbl2) > 30.) {
-                if ((fabs(tmp_dbl1) < 0.001) && (tmp_dbl2>330) && (tmp_dbl2<360)) {
-                    // singularity!
-                    // we have rot=0 for XCAL and rot>330 | rot<360 for input frame
-                } else {
-                cpl_msg_warning("","The angle of the calibration files (%g deg) "
-                                "and the angle of the frame to reconstruct"
-                                " (%g deg) differ by %g deg! Think about using "
-                                "calibration files matching better the actual "
-                                "rotator offset (ESO OCS ROT NAANGLE)",
-                                tmp_dbl1, tmp_dbl2,
-                                fabs(tmp_dbl1 - tmp_dbl2));
-                }
-            }
-
-            cpl_propertylist_delete(h1); h1 = NULL;
-            cpl_propertylist_delete(h2); h2 = NULL;
-            cpl_free(kw); kw = NULL;
-*/
         }
 
         KMO_TRY_EXIT_IF_NULL(
@@ -879,18 +780,13 @@ static int kmo_reconstruct(cpl_parameterlist *parlist, cpl_frameset *frameset)
                 print_cal_angle_msg_once = TRUE;
                 print_xcal_angle_msg_once = TRUE;
             }
-            char *tmp_band_method = getenv("KMO_BAND_METHOD");
-            int band_method = 0;
-            if (tmp_band_method != NULL) {
-                band_method = atoi(tmp_band_method);
-            }
 
             KMO_TRY_EXIT_IF_NULL(
                 band_table = kmo_dfs_load_table(frameset, WAVE_BAND, 1, FALSE));
 
             KMO_TRY_EXIT_IF_ERROR(
-                kmclipm_setup_grid_band_lcal(&gd, lcal, my_filter_id,
-                                             band_method, band_table));
+                kmclipm_setup_grid_band_lcal(&gd, my_filter_id,
+                                             band_table));
             cpl_table_delete(band_table); band_table = NULL;
 
             cpl_image_delete(lcal); lcal = NULL;
@@ -1028,78 +924,6 @@ static int kmo_reconstruct(cpl_parameterlist *parlist, cpl_frameset *frameset)
                                                 flux,
                                                 background,
                                                 xcal_interpolation));
-/*
- // show that lambda correction improved the data cube, a second one would improve even more
-
-                        cpl_bivector *obj_spectrum2, *obj_spectrum3;
-                        cpl_polynomial *lcorr_coeffs2, *lcorr_coeffs3;
-                        KMO_TRY_EXIT_IF_NULL(
-                                obj_spectrum2 = kmo_lcorr_extract_spectrum(
-                                        cube_data, actual_sub_header, 0.8, NULL));
-
-                        KMO_TRY_EXIT_IF_NULL(
-                                lcorr_coeffs2 = kmo_lcorr_crosscorrelate_spectra(
-                                        obj_spectrum2, ref_spectrum, peaks, 0.002));
-
-                        cpl_bivector_delete(obj_spectrum2);
-
-                        coeff_dump[0] = 0;
-                        for (ic=0; ic<=cpl_polynomial_get_degree(lcorr_coeffs2) && ic < max_coeffs; ic++) {
-                            pows[0] = ic;
-                            coeff_string = cpl_sprintf(" %*g,",
-                                    format_width-2, cpl_polynomial_get_coeff(lcorr_coeffs2,pows));
-                            strncat(coeff_dump, coeff_string, format_width);
-                            cpl_free(coeff_string);
-                            double c1 =  cpl_polynomial_get_coeff(lcorr_coeffs,pows);
-                            double c2 =  cpl_polynomial_get_coeff(lcorr_coeffs2,pows);
-                            cpl_polynomial_set_coeff(lcorr_coeffs, pows, c1+c2);
-                        }
-                        cpl_msg_debug("","Lambda correction coeffs for ifu %d %s",ifu_nr, coeff_dump);
-                        cpl_polynomial_delete(lcorr_coeffs2); lcorr_coeffs2=NULL;
-
-                        cpl_imagelist_delete(cube_data); cube_data = NULL;
-                        cpl_imagelist_delete(cube_noise); cube_noise = NULL;
-                        KMO_TRY_EXIT_IF_ERROR(
-                            kmo_reconstruct_sci(ifu_nr,
-                                                bounds[2*(ifu_nr-1)],
-                                                bounds[2*(ifu_nr-1)+1],
-                                                rec_frame,
-                                                input_frame_name,
-                                                NULL,
-                                                NULL,
-                                                NULL,
-                                                xcal_frame,
-                                                ycal_frame,
-                                                lcal_frame,
-                                                lcorr_coeffs,
-                                                &gd,
-                                                &cube_data,
-                                                &cube_noise,
-                                                flux,
-                                                background,
-                                                xcal_interpolation));
-
-                        KMO_TRY_EXIT_IF_NULL(
-                                obj_spectrum3 = kmo_lcorr_extract_spectrum(
-                                        cube_data, actual_sub_header, 0.8, NULL));
-
-                        KMO_TRY_EXIT_IF_NULL(
-                                lcorr_coeffs3 = kmo_lcorr_crosscorrelate_spectra(
-                                        obj_spectrum3, ref_spectrum, peaks, 0.002));
-
-                        cpl_bivector_delete(obj_spectrum3);
-
-                        coeff_dump[0] = 0;
-                        for (ic=0; ic<=cpl_polynomial_get_degree(lcorr_coeffs3) && ic < max_coeffs; ic++) {
-                            pows[0] = ic;
-                            coeff_string = cpl_sprintf(" %*g,",
-                                    format_width-2, cpl_polynomial_get_coeff(lcorr_coeffs3,pows));
-                            strncat(coeff_dump, coeff_string, format_width);
-                            cpl_free(coeff_string);
-                        }
-                        cpl_msg_debug("","Lambda correction coeffs for iFu %d %s",ifu_nr, coeff_dump);
-                        cpl_polynomial_delete(lcorr_coeffs3); lcorr_coeffs3=NULL;
-*/
                         cpl_polynomial_delete(lcorr_coeffs); lcorr_coeffs = NULL;
 
                     }
@@ -1208,7 +1032,7 @@ static int kmo_reconstruct(cpl_parameterlist *parlist, cpl_frameset *frameset)
                                          cpl_frame_get_filename(rec_frame), index));
                 KMO_TRY_EXIT_IF_ERROR(
                     kmo_save_det_img_ext(det_img_data[i-1], gd, i, filename_img,
-                                         obs_suffix, tmp_header, dev_flip, FALSE));
+                                         obs_suffix, tmp_header, FALSE, FALSE));
                 cpl_propertylist_delete(tmp_header); tmp_header = NULL;
 
                 if (detImgCube) {
@@ -1225,7 +1049,8 @@ static int kmo_reconstruct(cpl_parameterlist *parlist, cpl_frameset *frameset)
                                              cpl_frame_get_filename(rec_frame), index));
                     KMO_TRY_EXIT_IF_ERROR(
                         kmo_save_det_img_ext(det_img_noise[i-1], gd, i, filename_img,
-                                             obs_suffix, tmp_header, dev_flip, TRUE));
+                                             obs_suffix, tmp_header,
+                                             FALSE, TRUE));
                     cpl_propertylist_delete(tmp_header); tmp_header = NULL;
                 }
             }
@@ -1260,7 +1085,6 @@ static int kmo_reconstruct(cpl_parameterlist *parlist, cpl_frameset *frameset)
     cpl_free(suffix); suffix = NULL;
     cpl_free(filename_img); filename_img = NULL;
     cpl_free(filename_cube); filename_cube = NULL;
-//    sat_mode_msg = FALSE;
 
     return ret_val;
 }
