@@ -372,7 +372,7 @@ static int kmos_flat(cpl_parameterlist *parlist, cpl_frameset *frameset)
     const cpl_parameter *   par ;
     int                     surrounding_pixels, badpix_thresh, 
                             suppress_extension, reduce_det ;
-    double                  reduce_angle, cpos_rej, cneg_rej ;
+    double                  reduce_angle, cpos_rej, cneg_rej, ext_index ;
     int                     cmax, cmin, citer ;
     const char          *   cmethod ;
     cpl_frame           *   frame ;
@@ -784,33 +784,43 @@ static int kmos_flat(cpl_parameterlist *parlist, cpl_frameset *frameset)
     cpl_propertylist_delete(main_header_xcal);
 
     /* -------- saving sub frames  */
+    ext_index = 0 ;
     for (a = 0; a < nb_angles; a++) {
+        /* Reduce only one angle */
+        if (reduce_angle <= 360 && angles_array[a] != reduce_angle) continue ;
+        
         for (i = 1; i <= ne; i++) {
+            /* Compute only one detector */
+            if (reduce_det != 0 && i != reduce_det) continue ;
+            
             sx = a * ne + (i - 1);
-
             // load stored data again
-            stored_flat[sx]=kmclipm_image_load(fn_flat, CPL_TYPE_FLOAT, 0, sx);
+            stored_flat[sx]=kmclipm_image_load(fn_flat, CPL_TYPE_FLOAT, 0, 
+                    ext_index);
             cpl_error_reset() ;
-            stored_noise[sx]=kmclipm_image_load(fn_noise, CPL_TYPE_FLOAT, 0,sx);
+            stored_noise[sx]=kmclipm_image_load(fn_noise, CPL_TYPE_FLOAT, 0, 
+                    ext_index);
             cpl_error_reset() ;
-            stored_badpix[sx]=kmclipm_image_load(fn_badpix,CPL_TYPE_FLOAT,0,sx);
+            stored_badpix[sx]=kmclipm_image_load(fn_badpix,CPL_TYPE_FLOAT, 0,
+                    ext_index);
             cpl_error_reset() ;
-
+            ext_index ++ ;
+            
             sub_header = kmo_dfs_load_sub_header(frameset, FLAT_ON, i, FALSE);
             kmclipm_update_property_double(sub_header,CAL_ROTANGLE, 
                     ((double) angles_array[a]), 
                     "[deg] Rotator relative to nasmyth");
-
+            
             if (spec_found[sx] == CPL_ERROR_NONE) {
                 kmclipm_update_property_int(sub_header, QC_FLAT_SAT, 
                         stored_qc_flat_sat[sx],
                         "[] nr. saturated pixels of master flat");
                 /* Load gain */
                 gain = kmo_dfs_get_property_double(sub_header, GAIN);
-
                 kmclipm_update_property_double(sub_header, QC_FLAT_EFF,
                         stored_qc_flat_eff[sx]/gain,
                         "[e-/s] rel. brightness of flat lamp");
+             
                 kmclipm_update_property_double(sub_header, QC_FLAT_SN, 
                         stored_qc_flat_sn[sx], "[] S/N of master flat");
             }
@@ -836,7 +846,6 @@ static int kmos_flat(cpl_parameterlist *parlist, cpl_frameset *frameset)
                         stored_slitmaxdev[sx],
                         "[pix] max slitlet width deviation");
             }
-
         
             /* Calculate QC.BADPIX.NCOUNT */
             /* Remove 4pixel-border as bad pixels */
